@@ -381,7 +381,7 @@ class Assets(WMLResource):
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def download(self, asset_uid, filename):
         """
-            Download the content of a data asset.
+            Download and store the content of a data asset.
 
             **Parameters**
 
@@ -397,14 +397,46 @@ class Assets(WMLResource):
 
             .. important::
 
-                 **returns**: Path to the downloaded asset content\n
+                 **returns**: Normalized path to the downloaded asset content\n
                  **return type**: str\n
 
             **Example**
 
              >>> client.data_assets.download(asset_uid,"sample_asset.csv")
          """
+        content = self.get_content(asset_uid)
+        try:
+            with open(filename, 'wb') as f:
+                f.write(content)
+            print(Messages.get_message(filename, message_id="successfully_saved_data_asset_content_to_file"))
+            return os.path.abspath(filename)
+        except IOError as e:
+            raise WMLClientError(
+                Messages.get_message(filename, message_id="saving_data_asset_to_local_file_failed"), e)
 
+    @docstring_parameter({'str_type': STR_TYPE_NAME})
+    def get_content(self, asset_uid):
+        """
+            Download the content of a data asset.
+
+            **Parameters**
+
+            .. important::
+
+                 #. **asset_uid**:  The Unique Id of the data asset to be downloaded\n
+                    **type**: str\n
+
+            **Output**
+
+            .. important::
+
+                 **returns**: the asset content\n
+                 **return type**: binary\n
+
+            **Example**
+
+             >>> content = client.data_assets.get_content(asset_uid).decode('ascii')
+        """
         Assets._validate_type(asset_uid, u'asset_uid', STR_TYPE, True)
 
         import urllib
@@ -428,14 +460,7 @@ class Assets(WMLResource):
             if r.status_code != 200:
                 raise ApiRequestFailure(Messages.get_message(message_id="failure_during_downloading_data_asset"), r)
 
-            downloaded_asset = r.content
-            try:
-                with open(filename, 'wb') as f:
-                    f.write(downloaded_asset)
-                print(Messages.get_message(filename, message_id="successfully_saved_data_asset_content_to_file"))
-                return os.getcwd() + "/" + filename
-            except IOError as e:
-                raise WMLClientError(Messages.get_message(filename, message_id="saving_data_asset_to_local_file_failed"), e)
+            return r.content
         else:
             attachment_id = asset_details["attachments"][0]["id"]
             if not self._ICP and not self._client.WSD:
@@ -473,14 +498,7 @@ class Assets(WMLResource):
                 if att_response.status_code != 200:
                     raise ApiRequestFailure(Messages.get_message(message_id="failure_during_downloading_data_asset"), att_response)
 
-                downloaded_asset = att_response.content
-                try:
-                    with open(filename, 'wb') as f:
-                        f.write(downloaded_asset)
-                    print(Messages.get_message(filename, message_id="successfully_saved_data_asset_content_to_file"))
-                    return os.getcwd() + "/" + filename
-                except IOError as e:
-                    raise WMLClientError(Messages.get_message(filename, message_id="saving_data_asset_to_local_file_failed"), e)
+                return att_response.content
             else:
                 raise WMLClientError(Messages.get_message(message_id="failure_during_downloading_data_asset"))
 
