@@ -22,6 +22,7 @@ from ibm_watson_machine_learning.wml_resource import WMLResource
 from ibm_watson_machine_learning.wml_client_error import WMLClientError, ApiRequestFailure
 import os
 import json
+from urllib.parse import unquote
 
 _DEFAULT_LIST_LENGTH = 0
 
@@ -413,6 +414,37 @@ class Connections(WMLResource):
 
         self._list(space_values, [u'NAME', u'ID', u'CREATED',  u'DATASOURCE_TYPE_ID', ], None, None)
 
+    @docstring_parameter({'str_type': STR_TYPE_NAME})
+    def list_uploaded_db_drivers(self):
+        """
+           List uploaded db driver jars.
+           Supported for IBM Cloud Pak for Data only.
+
+           **Output**
+
+           .. important::
+                This method only prints the uploaded db driver jar names.\n
+                **return type**: Str\n
+
+           **Example**
+
+            >>> client.connections.list_uploaded_db_drivers()
+
+        """
+        if not self._client.ICP:
+            raise WMLClientError('Not supported on this environment.')
+        
+        response = requests.get(
+            self._client.service_instance._href_definitions.get_wsd_model_attachment_href() + 'dbdrivers',
+            headers=self._client._get_headers(no_content_type=True),
+            params=self._client._params(),
+            verify=not self._client.ICP
+        )
+        jars = [[el['path'].split('/')[-1]] for el in response.json()['resources']]
+
+        self._list(jars, [u'NAME'], None, None)
+
+
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_datasource_type_uid_by_name(self, name):
         """
@@ -455,3 +487,81 @@ class Connections(WMLResource):
                 datasource_id = ds_resource['metadata']['asset_id']
         return datasource_id
 
+    @docstring_parameter({'str_type': STR_TYPE_NAME})
+    def upload_db_driver(self, path: str):
+        """
+           List uploaded db driver jars.
+           Supported for IBM Cloud Pak for Data only.
+
+           **Parameters**
+
+           .. important::
+                #. **path**:  path to db driver jar\n
+                   **type**: str\n
+
+           **Example**
+
+            >>> client.connections.upload_db_driver('example/path/db2jcc4.jar')
+
+        """
+        if not self._client.ICP:
+            raise WMLClientError('Not supported on this environment.')
+
+        import urllib
+        import requests
+
+        driver_file_name = path.split('/')[-1]
+
+        with open(path, 'rb') as fdata:
+            content_upload_url = self._client.service_instance._href_definitions.get_wsd_model_attachment_href() + \
+                                 "dbdrivers/" + urllib.parse.quote(driver_file_name, safe='')
+            response = requests.put(
+                content_upload_url,
+                files={'file': ('native', fdata, 'application/octet-stream', {'Expires': '0'})},
+                headers=self._client._get_headers(no_content_type=True),
+                params=self._client._params(),
+                verify=False
+            )
+
+            self._client.repository._handle_response(201, 'uploading db driver jar', response)
+
+    @docstring_parameter({'str_type': STR_TYPE_NAME})
+    def sign_db_driver_url(self, jar_name: str):
+        """
+           Get signed db driver jar url to be used during creating of JDBC generic connection. The jar name passed as argument needs to be uploaded into system first.
+           Supported for IBM Cloud Pak for Data only.
+
+           **Parameters**
+
+           .. important::
+                #. **jar_name**:  db driver jar name\n
+                   **type**: str\n
+
+           **Example**
+
+            >>> client.connections.sign_db_driver_url('db2jcc4.jar')
+
+        """
+        if not self._client.ICP:
+            raise WMLClientError('Not supported on this environment.')
+
+        import urllib
+        import requests
+
+        signed_url = self._client.service_instance._href_definitions.get_wsd_model_attachment_href() + \
+                     urllib.parse.quote("dbdrivers/" + jar_name, safe='') + "/signed"
+        params = self._client._params()
+
+        params['expires_in'] = 5000
+
+        response = requests.post(
+            signed_url,
+            headers=self._client._get_headers(no_content_type=True),
+            params=params,
+            verify=False
+        )
+
+        self._client.repository._handle_response(201, 'signing db driver url', response, json_response=False)
+
+        return unquote(response.headers['Location'])
+
