@@ -172,18 +172,10 @@ class BaseDeployment(ABC):
         """
 
         if kwargs.get('serving_name'):
-            url = self._source_workspace.wml_client.service_instance._href_definitions.get_deployments_href() + f"/serving_name/{kwargs.get('serving_name')}"
-            res = requests.get(url,
-                               headers=self._source_workspace.wml_client._get_headers(),
-                               params=self._source_workspace.wml_client._params(),
-                               verify=not self._source_workspace.wml_client.ICP)
+            status_code, response = self._target_workspace.wml_client.deployments._get_serving_name_info(kwargs.get('serving_name'))
 
-            if res.status_code == 404:
-                pass  # endpoint for checking availability is not available on this cluster
-            else:
-                result = self._source_workspace.wml_client.repository._handle_response(200, 'checking serving name availability', res)
-                if not result['available']:
-                    raise ServingNameNotAvailable(result['message'])
+            if status_code == 409:
+                raise ServingNameNotAvailable(response['errors'][0])
 
         # note: This section is only for deployments with specified experiment_id
         if kwargs['experiment_run_id'] is not None:
