@@ -766,7 +766,7 @@ class WMLEngine(BaseEngine):
         }
 
         # note: retrieve all additional pipeline evaluation information
-        for pipeline in run_params['entity']['status'].get('metrics', []):
+        for pipeline in run_params['entity']['status'].get('metrics', [])[::-1]:
             if pipeline['context']['intermediate_model']['name'].split('P')[-1] == pipeline_name.split('_')[-1]:
 
                 pipeline_parameters['composition_steps'] = pipeline['context']['intermediate_model'][
