@@ -772,7 +772,7 @@ class RemoteAutoPipelines(BaseAutoPipelines):
         optimizer_parameters = self.get_params()
         run_details = self.get_run_details()
 
-        if 'test_data_references' not in run_details['entity']:
+        if not run_details['entity'].get('test_data_references'):
             raise TestDataNotPresent(reason="User specified test data was not present in this experiment. "
                                             "Try to use 'with_holdout_split' parameter for original "
                                             "training_data_references to retrieve test data.")
