@@ -52,7 +52,8 @@ from ibm_watson_machine_learning.utils.autoai.errors import (
 )
 
 import numpy as np
-from ibm_watson_machine_learning.utils.autoai.utils import all_logging_disabled, try_import_autoai_libs
+from ibm_watson_machine_learning.utils.autoai.utils import all_logging_disabled, try_import_autoai_libs, \
+    try_import_autoai_ts_libs
 from ibm_watson_machine_learning.utils.autoai.watson_studio import get_project
 from ibm_watson_machine_learning.wml_client_error import MissingValue, ApiRequestFailure
 from .base_connection import BaseConnection
@@ -378,75 +379,114 @@ class DataConnection(BaseDataConnection):
             with_holdout_split: bool = True
     ) -> Union[Tuple['DataFrame', 'DataFrame'], Tuple['DataFrame', 'DataFrame', 'DataFrame', 'DataFrame']]:
         """This method tries to recreate holdout data."""
-        try_import_autoai_libs(minimum_version='1.12.14')
-        from autoai_libs.utils.holdout_utils import make_holdout_split, numpy_split_on_target_values
-        from autoai_libs.utils.sampling_utils import numpy_sample_rows
 
-        data.replace([np.inf, -np.inf], np.nan, inplace=True)
-        data.drop_duplicates(inplace=True)
-        data.dropna(subset=[self.auto_pipeline_params['prediction_column']], inplace=True)
-        dfy = data[self.auto_pipeline_params['prediction_column']]
-        data.drop(columns=[self.auto_pipeline_params['prediction_column']], inplace=True)
+        if self.auto_pipeline_params.get('prediction_columns') is not None:
+            # timeseries
+            try_import_autoai_ts_libs()
+            from autoai_ts_libs.utils.holdout_utils import make_holdout_split
 
-        y_column = [self.auto_pipeline_params['prediction_column']]
-        X_columns = data.columns
+            # Note: When lookback window is auto detected there is need to get the detected value from training details
+            if self.auto_pipeline_params.get('lookback_window') == -1 or self.auto_pipeline_params.get('lookback_window') is None:
+                ts_metrics = self._wml_client.training.get_details(self.auto_pipeline_params.get('run_id'))['entity']['status']['metrics']
+                final_ts_state_name = "after_final_pipelines_generation"
 
-        if self._test_data or not with_holdout_split:
-            return data, dfy
 
-        else:
-            ############################
-            #   REMOVE MISSING ROWS    #
-            from autoai_libs.utils.holdout_utils import numpy_remove_missing_target_rows
-            # Remove (and save) the rows of X and y for which the target variable has missing values
-            data, dfy, _, _, _, _ = numpy_remove_missing_target_rows(
-                y=dfy, X=data
-            )
-            #   End of REMOVE MISSING ROWS    #
-            ###################################
+                for metric in ts_metrics:
+                    if metric['context']['intermediate_model']['process'] == final_ts_state_name:
+                        self.auto_pipeline_params['lookback_window'] = metric['context']['timeseries']['lookback_window']
+                        break
 
-            #################
-            #   SAMPLING    #
-            # Get a sample of the rows if requested and applicable
-            # (check for sampling is performed inside this function)
-            try:
-                data, dfy, _ = numpy_sample_rows(
-                    X=data,
-                    y=dfy,
-                    train_sample_rows_test_size=self.auto_pipeline_params['train_sample_rows_test_size'],
-                    learning_type=self.auto_pipeline_params['prediction_type'],
-                    return_sampled_indices=True
-                )
-
-            # Note: we have a silent error here (the old core behaviour)
-            # sampling is not performed as 'train_sample_rows_test_size' is bigger than data rows count
-            # TODO: can we throw an error instead?
-            except ValueError as e:
-                if 'between' in str(e):
-                    pass
-
-                else:
-                    raise e
-            #   End of SAMPLING    #
-            ########################
-
-            # Perform holdout split
-            X_train, X_holdout, y_train, y_holdout, _, _ = make_holdout_split(
-                x=data,
-                y=dfy,
-                learning_type=self.auto_pipeline_params['prediction_type'],
-                fairness_info=self.auto_pipeline_params.get('fairness_info', None),
-                test_size=self.auto_pipeline_params['holdout_size'],
+            # Note: imputation is not supported
+            X_train, X_holdout, y_train, y_holdout, _, _, _, _ = make_holdout_split(
+                dataset=data,
+                target_columns=self.auto_pipeline_params.get('prediction_columns'),
+                learning_type="forecasting",
+                test_size=self.auto_pipeline_params.get('holdout_size'),
+                lookback_window=self.auto_pipeline_params.get('lookback_window'),
+                # feature_columns=None,
+                timestamp_column=self.auto_pipeline_params.get('timestamp_column_name'),
+                # n_jobs=None,
+                # tshirt_size=None,
                 return_only_holdout=False
             )
 
-            X_train = DataFrame(X_train, columns=X_columns)
-            X_holdout = DataFrame(X_holdout, columns=X_columns)
-            y_train = DataFrame(y_train, columns=y_column)
-            y_holdout = DataFrame(y_holdout, columns=y_column)
+            X_train = DataFrame(X_train, columns=self.auto_pipeline_params['prediction_columns'])
+            X_holdout = DataFrame(X_holdout, columns=self.auto_pipeline_params['prediction_columns'])
+            y_train = DataFrame(y_train, columns=self.auto_pipeline_params['prediction_columns'])
+            y_holdout = DataFrame(y_holdout, columns=self.auto_pipeline_params['prediction_columns'])
 
             return X_train, X_holdout, y_train, y_holdout
 
+        else:
+            try_import_autoai_libs(minimum_version='1.12.14')
+            from autoai_libs.utils.holdout_utils import make_holdout_split, numpy_split_on_target_values
+            from autoai_libs.utils.sampling_utils import numpy_sample_rows
+
+            data.replace([np.inf, -np.inf], np.nan, inplace=True)
+            data.drop_duplicates(inplace=True)
+            data.dropna(subset=[self.auto_pipeline_params['prediction_column']], inplace=True)
+            dfy = data[self.auto_pipeline_params['prediction_column']]
+            data.drop(columns=[self.auto_pipeline_params['prediction_column']], inplace=True)
+
+            y_column = [self.auto_pipeline_params['prediction_column']]
+            X_columns = data.columns
+
+            if self._test_data or not with_holdout_split:
+                return data, dfy
+
+            else:
+                ############################
+                #   REMOVE MISSING ROWS    #
+                from autoai_libs.utils.holdout_utils import numpy_remove_missing_target_rows
+                # Remove (and save) the rows of X and y for which the target variable has missing values
+                data, dfy, _, _, _, _ = numpy_remove_missing_target_rows(
+                    y=dfy, X=data
+                )
+                #   End of REMOVE MISSING ROWS    #
+                ###################################
+
+                #################
+                #   SAMPLING    #
+                # Get a sample of the rows if requested and applicable
+                # (check for sampling is performed inside this function)
+                try:
+                    data, dfy, _ = numpy_sample_rows(
+                        X=data,
+                        y=dfy,
+                        train_sample_rows_test_size=self.auto_pipeline_params['train_sample_rows_test_size'],
+                        learning_type=self.auto_pipeline_params['prediction_type'],
+                        return_sampled_indices=True
+                    )
+
+                # Note: we have a silent error here (the old core behaviour)
+                # sampling is not performed as 'train_sample_rows_test_size' is bigger than data rows count
+                # TODO: can we throw an error instead?
+                except ValueError as e:
+                    if 'between' in str(e):
+                        pass
+
+                    else:
+                        raise e
+                #   End of SAMPLING    #
+                ########################
+
+                # Perform holdout split
+                X_train, X_holdout, y_train, y_holdout, _, _ = make_holdout_split(
+                    x=data,
+                    y=dfy,
+                    learning_type=self.auto_pipeline_params['prediction_type'],
+                    fairness_info=self.auto_pipeline_params.get('fairness_info', None),
+                    test_size=self.auto_pipeline_params['holdout_size'],
+                    return_only_holdout=False
+                )
+
+                X_train = DataFrame(X_train, columns=X_columns)
+                X_holdout = DataFrame(X_holdout, columns=X_columns)
+                y_train = DataFrame(y_train, columns=y_column)
+                y_holdout = DataFrame(y_holdout, columns=y_column)
+
+                return X_train, X_holdout, y_train, y_holdout
+
     def read(self,
              with_holdout_split: bool = False,
              csv_separator: str = ',',
@@ -520,6 +560,16 @@ class DataConnection(BaseDataConnection):
             self.auto_pipeline_params['holdout_size'] = experiment_metadata.get('holdout_size')
             self.auto_pipeline_params['prediction_type'] = experiment_metadata['prediction_type']
             self.auto_pipeline_params['fairness_info'] = experiment_metadata.get('fairness_info')
+            self.auto_pipeline_params['lookback_window'] = experiment_metadata.get('lookback_window')
+            self.auto_pipeline_params['timestamp_column_name'] = experiment_metadata.get('timestamp_column_name')
+
+            # note: check for cloud
+            if isinstance(experiment_metadata['training_result_reference'].location, (S3Location, AssetLocation)):
+                run_id = experiment_metadata['training_result_reference'].location._training_status.split('/')[-2]
+            # WMLS
+            else:
+                run_id = experiment_metadata['training_result_reference'].location.path.split('/')[-3]
+            self.auto_pipeline_params['run_id'] = run_id
 
             if self._test_data:
                 csv_separator = experiment_metadata.get('test_data_csv_separator', csv_separator)
@@ -670,7 +720,8 @@ class DataConnection(BaseDataConnection):
         if isinstance(data, DataFrame) and 'Unnamed: 0' in data.columns.tolist():
             data.drop(['Unnamed: 0'], axis=1, inplace=True)
 
-        if raw or self.auto_pipeline_params.get('prediction_column') is None:
+        if raw or (self.auto_pipeline_params.get('prediction_column') is None
+                   and self.auto_pipeline_params.get('prediction_columns') is None):
             return data
 
         else:
@@ -679,9 +730,13 @@ class DataConnection(BaseDataConnection):
                 return X_train, X_holdout, y_train, y_holdout
 
             else:  # when this data connection is a test / holdout one
-                test_X, test_y = self._recreate_holdout(data=data, with_holdout_split=False)
-                test_X[self.auto_pipeline_params.get('prediction_column', 'prediction_column')] = test_y
-                return test_X   # return one dataframe
+                if self.auto_pipeline_params.get('prediction_columns') is not None:
+                    # timeseries dataset does not have prediction columns. Whole data set is returned:
+                    test_X = data
+                else:
+                    test_X, test_y = self._recreate_holdout(data=data, with_holdout_split=False)
+                    test_X[self.auto_pipeline_params.get('prediction_column', 'prediction_column')] = test_y
+                return test_X  # return one dataframe
 
     def write(self, data: Union[str, 'DataFrame'], remote_name: str = None, **kwargs) -> None:
         """
