@@ -179,7 +179,8 @@ class PlatformSpaces(WMLResource):
         if background_mode:
             print("Space has been created. However some background setup activities might still be on-going. "
                   "Check for 'status' field in the response. It has to show 'active' before space can be used. "
-                  "If its not 'active', you can monitor the state with a call to spaces.get_details(space_id)")
+                  "If it's not 'active', you can monitor the state with a call to spaces.get_details(space_id). "
+                  "Alternatively, use background_mode=False when calling client.spaces.store().")
             return spaces_details
 
         else:
