@@ -1,3 +1,17 @@
+#  (C) Copyright IBM Corp. 2021.
+#
+#  Licensed under the Apache License, Version 2.0 (the "License");
+#  you may not use this file except in compliance with the License.
+#  You may obtain a copy of the License at
+#
+#       http://www.apache.org/licenses/LICENSE-2.0
+#
+#  Unless required by applicable law or agreed to in writing, software
+#  distributed under the License is distributed on an "AS IS" BASIS,
+#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#  See the License for the specific language governing permissions and
+#  limitations under the License.
+
 import abc
 import os
 from datetime import datetime
@@ -14,6 +28,8 @@ from ibm_watson_machine_learning.experiment.autoai.optimizers import RemoteAutoP
 from ibm_watson_machine_learning.helpers.connections import DataConnection, AssetLocation, \
     DeploymentOutputAssetLocation, S3Location
 from ibm_watson_machine_learning.tests.utils import save_data_to_cos_bucket
+from ibm_watson_machine_learning.utils.autoai.errors import WMLClientError
+
 from ibm_watson_machine_learning.tests.utils.cleanup import space_cleanup, delete_model_deployment
 from ibm_watson_machine_learning.utils.autoai.enums import TShirtSize, PredictionType
 
@@ -43,6 +59,7 @@ class AbstractTestBatch(abc.ABC):
     wml_credentials: str
     service_batch: 'Batch'
 
+    connection_id = None
     asset_id: str
     batch_payload_location: str
     batch_payload_cos_location: str
@@ -335,9 +352,12 @@ class AbstractTestBatch(abc.ABC):
         self.wml_client.set.default_space(self.target_space_id) if not self.wml_client.default_space_id else None
         self.wml_client.repository.delete(AbstractTestBatch.service_batch.asset_id)
 
-        print(f"Delete all created assets in Batch deployment tests. {AbstractTestBatch.data_assets_to_delete}")
-        for asset_id in AbstractTestBatch.data_assets_to_delete:
-            self.wml_client.data_assets.delete(asset_id)
+        try:
+            print(f"Delete all created assets in Batch deployment tests. {AbstractTestBatch.data_assets_to_delete}")
+            for asset_id in AbstractTestBatch.data_assets_to_delete:
+                self.wml_client.data_assets.delete(asset_id)
+        except WMLClientError:
+            print("Not able to dele data assets")
 
         self.assertEqual(AbstractTestBatch.service_batch.id, None, msg="Deployment ID deleted incorrectly")
         self.assertEqual(AbstractTestBatch.service_batch.name, None, msg="Deployment name deleted incorrectly")
