@@ -1,3 +1,17 @@
+#  (C) Copyright IBM Corp. 2021.
+#
+#  Licensed under the Apache License, Version 2.0 (the "License");
+#  you may not use this file except in compliance with the License.
+#  You may obtain a copy of the License at
+#
+#       http://www.apache.org/licenses/LICENSE-2.0
+#
+#  Unless required by applicable law or agreed to in writing, software
+#  distributed under the License is distributed on an "AS IS" BASIS,
+#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#  See the License for the specific language governing permissions and
+#  limitations under the License.
+
 import abc
 import os
 
@@ -18,6 +32,7 @@ from ibm_watson_machine_learning.tests.utils import (get_wml_credentials, get_co
                                                      save_data_to_cos_bucket)
 from ibm_watson_machine_learning.tests.utils.cleanup import space_cleanup, delete_model_deployment
 from ibm_watson_machine_learning.utils.autoai.enums import PredictionType, RunStateTypes
+from ibm_watson_machine_learning.utils.utils import WMLClientError
 
 from ibm_watson_machine_learning.tests.utils.assertions import get_and_predict_all_pipelines_as_lale, \
     validate_autoai_experiment
@@ -195,10 +210,6 @@ class AbstractTestOBM(abc.ABC):
 
         AbstractTestOBM.remote_auto_pipelines = self.experiment.optimizer(**AbstractTestOBM.experiment_info)
 
-        self.assertIsInstance(AbstractTestOBM.remote_auto_pipelines, RemoteAutoPipelines,
-                              msg=f"experiment.optimizer did not return RemoteAutoPipelines object, "
-                                  f"type: {type(AbstractTestOBM.remote_auto_pipelines)}")
-
     def test_06_get_configuration_parameters_of_remote_auto_pipeline(self):
         print("Getting experiment configuration parameters...")
         parameters = self.remote_auto_pipelines.get_params()
@@ -765,9 +776,12 @@ class AbstractTestOBM(abc.ABC):
         self.assertEqual(AbstractTestOBM.service_batch.scoring_url, None,
                          msg="Deployment scoring_url deleted incorrectly")
 
-        print(f"Delete all created assets in Batch deployment tests. {AbstractTestOBM.data_assets_to_delete}")
-        for asset_id in AbstractTestOBM.data_assets_to_delete:
-            self.wml_client.data_assets.delete(asset_id)
+        try:
+            print(f"Delete all created assets in Batch deployment tests. {AbstractTestOBM.data_assets_to_delete}")
+            for asset_id in AbstractTestOBM.data_assets_to_delete:
+                self.wml_client.data_assets.delete(asset_id)
+        except WMLClientError:
+            print("Not able to delete data assets")
 
         print(f"Delete connection used in Batch deployment tests. {AbstractTestOBM.connection_id}")
-        self.wml_client.connections.delete(AbstractTestOBM.connection_id)
\ No newline at end of file
+        self.wml_client.connections.delete(AbstractTestOBM.connection_id)
