@@ -188,14 +188,20 @@ class AbstractTestTSAsync(abc.ABC):
                              msg='DataConnection auto_pipeline_params was not updated.')
 
     def test_06_get_train_data(self):
-        AbstractTestTSAsync.train_data = self.remote_auto_pipelines.get_data_connections()[0].read()
+        # AbstractTestTSAsync.train_data = self.remote_auto_pipelines.get_data_connections()[0].read()
+        #
+        # print("train data sample:")
+        # print(self.train_data.head())
+        # self.assertGreater(len(self.train_data), 0)
+
+        AbstractTestTSAsync.train_X, AbstractTestTSAsync.test_X, AbstractTestTSAsync.train_y, AbstractTestTSAsync.test_y = \
+            self.remote_auto_pipelines.get_data_connections()[0].read(with_holdout_split=True)
+
+        AbstractTestTSAsync.scoring_df = self.train_X[:10]
 
         print("train data sample:")
-        print(self.train_data.head())
-        self.assertGreater(len(self.train_data), 0)
-
-        AbstractTestTSAsync.scoring_df = self.train_data[self.experiment_info['prediction_columns']][
-                                         :10]
+        print(self.train_X.head())
+        self.assertGreater(len(self.train_X), 0)
 
     def test_07_get_run_status(self):
         status = self.remote_auto_pipelines.get_run_status()
@@ -217,7 +223,7 @@ class AbstractTestTSAsync(abc.ABC):
         self.assertGreater(len(metrics), 0)
 
     def test_09_predict_using_fitted_pipeline(self):
-        predictions = self.remote_auto_pipelines.predict(X=self.train_data[:5])
+        predictions = self.remote_auto_pipelines.predict(X=self.train_X)
         print(predictions)
         self.assertGreater(len(predictions), 0)
 
