@@ -49,63 +49,21 @@ class TestAutoAIRemote(AbstractTestAutoAIRemote, unittest.TestCase):
     connection_asset_details = json.loads(config.get(get_env(), 'jdbc_db2_connection_asset_details'))
 
     def test_00c_prepare_connection_to_db2(self):
-        # import urllib
-        # import requests
-        #
-        # driver_file_path = self.connection_asset_details['driver_file_path']
-        # driver_file_name = driver_file_path.split('/')[-1]
-        #
-        # signed_url = self.wml_client.service_instance._href_definitions.get_wsd_model_attachment_href() + '/' + \
-        #                              urllib.parse.quote("dbdrivers/" + driver_file_name + "/sign", safe='')
-        # params = self.wml_client._params()
-        #
-        # params['expires_in'] = 60*60*24
-        #
-        # response = requests.post(
-        #     signed_url,
-        #     headers=self.wml_client._get_headers(no_content_type=True),
-        #     params=params,
-        #     verify=False
-        # )
-        #
-        # print(response.json())
+        driver_file_path = self.connection_asset_details['driver_file_path']
+        driver_file_name = driver_file_path.split('/')[-1]
 
+        self.wml_client.connections.upload_db_driver(driver_file_path)
+        self.wml_client.connections.list_uploaded_db_drivers()
 
-        # with open(driver_file_path, 'rb') as fdata:
-        #     content_upload_url = self.wml_client.service_instance._href_definitions.get_wsd_model_attachment_href() + '/' + \
-        #                          urllib.parse.quote("dbdrivers/" + driver_file_name, safe='')
-        #     response = requests.put(
-        #         content_upload_url,
-        #         files={'file': ('native', fdata, 'application/octet-stream', {'Expires': '0'})},
-        #         headers=self.wml_client._get_headers(no_content_type=True),
-        #         params=self.wml_client._params(),
-        #         verify=False
-        #     )
-        #     if response.status_code == 201:
-        #         print(response.text)
-        #         # asset_body = {
-        #         #     "asset_type": "wml_model",
-        #         #     "name": "native",
-        #         #     "object_key": asset_uid + "/" + file_name_to_attach,
-        #         #     "object_key_is_read_only": True
-        #         # }
-        #         # attach_payload = json.dumps(asset_body, separators=(',', ':'))
-        #         #
-        #         # attach_response = requests.post(attach_url,
-        #         #                                 data=attach_payload,
-        #         #                                 params=params,
-        #         #                                 headers=headers,
-        #         #                                 verify=False)
-        #     else:
-        #         print(response.text)
-        #         raise Exception(f"Failed while uploading driver: {response.text}")
+        properties = self.connection_asset_details['properties']
+        properties['jar_uris'] = self.wml_client.connections.sign_db_driver_url(driver_file_name)
 
         connection_details = self.wml_client.connections.create({
             'datasource_type': self.wml_client.connections.get_datasource_type_uid_by_name(
                 self.connection_asset_details['datasource_type_name']
             ),
             'name': 'Connection to DB2 for tests',
-            'properties': self.connection_asset_details['properties']
+            'properties': properties
         })
 
         TestAutoAIRemote.connection_id = self.wml_client.connections.get_uid(connection_details)
