@@ -49,12 +49,21 @@ class TestAutoAIRemote(AbstractTestAutoAIRemote, unittest.TestCase):
     connection_asset_details = json.loads(config.get(get_env(), 'jdbc_postgres_connection_asset_details'))
 
     def test_00c_prepare_connection_to_postgres(self):
+        driver_file_path = self.connection_asset_details['driver_file_path']
+        driver_file_name = driver_file_path.split('/')[-1]
+
+        self.wml_client.connections.upload_db_driver(driver_file_path)
+        self.wml_client.connections.list_uploaded_db_drivers()
+
+        properties = self.connection_asset_details['properties']
+        properties['jar_uris'] = self.wml_client.connections.sign_db_driver_url(driver_file_name)
+
         connection_details = self.wml_client.connections.create({
             'datasource_type': self.wml_client.connections.get_datasource_type_uid_by_name(
                 self.connection_asset_details['datasource_type_name']
             ),
             'name': 'Connection to Postgres for tests',
-            'properties': self.connection_asset_details['properties']
+            'properties': properties
         })
 
         TestAutoAIRemote.connection_id = self.wml_client.connections.get_uid(connection_details)
