@@ -273,9 +273,9 @@ class TestAutoAIRemote(unittest.TestCase):
     def test_08b_get_metrics(self):
         self.wml_client.training.get_metrics(self.run_id)
 
-    def test_09_predict_using_fitted_pipeline(self):
-        with self.assertRaises(ForecastingUnsupportedOperation, msg="Operation should be unsupported"):
-            self.remote_auto_pipelines.predict(X=self.X_values[:5])
+    # def test_09_predict_using_fitted_pipeline(self):
+    #     with self.assertRaises(ForecastingUnsupportedOperation, msg="Operation should be unsupported"):
+    #         self.remote_auto_pipelines.predict(X=self.X_values[:5])
 
     def test_10_summary_listing_all_pipelines_from_wml(self):
         pipelines_summary = self.remote_auto_pipelines.summary()
@@ -299,21 +299,6 @@ class TestAutoAIRemote(unittest.TestCase):
         best_pipeline_params = self.remote_auto_pipelines.get_pipeline_details()
         print(best_pipeline_params)
 
-    ####
-    # LALE #
-    ########
-
-    def test_14__get_pipeline__load_lale_pipeline__pipeline_loaded(self):
-        with self.assertRaises(ForecastingUnsupportedOperation, msg="Operation should be unsupported"):
-            self.remote_auto_pipelines.get_pipeline(pipeline_name='Pipeline_4')
-
-    def test_15_get_all_pipelines_as_lale(self):
-        summary = self.remote_auto_pipelines.summary()
-        print(summary.to_string())
-        for pipeline_name in summary.reset_index()['Pipeline Name']:
-            print(f"Getting pipeline: {pipeline_name}")
-            with self.assertRaises(ForecastingUnsupportedOperation, msg="Operation should be unsupported"):
-                self.remote_auto_pipelines.get_pipeline(pipeline_name=pipeline_name)
 
     #################################
     #      DEPLOYMENT SECTION       #
