@@ -1,3 +1,17 @@
+#  (C) Copyright IBM Corp. 2021.
+#
+#  Licensed under the Apache License, Version 2.0 (the "License");
+#  you may not use this file except in compliance with the License.
+#  You may obtain a copy of the License at
+#
+#       http://www.apache.org/licenses/LICENSE-2.0
+#
+#  Unless required by applicable law or agreed to in writing, software
+#  distributed under the License is distributed on an "AS IS" BASIS,
+#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#  See the License for the specific language governing permissions and
+#  limitations under the License.
+
 import unittest
 import traceback
 
@@ -60,7 +74,7 @@ def validate_autoai_timeseries_experiment(experiment_info, autoai_pod_version):
         experiment_info['prediction_type'] = PredictionType.FORECASTING
 
     test_case.assertEqual(experiment_info['prediction_type'], PredictionType.FORECASTING,
-                          msg="Prediction type for TS experiment was set incorrectly ")
+                          msg="Prediction type for forecasting experiment was set incorrectly ")
 
     if "autoai_pod_version" not in experiment_info.keys():
         experiment_info['autoai_pod_version'] = autoai_pod_version
