@@ -23,6 +23,7 @@ import time
 from ibm_watson_machine_learning.metanames import TrainingConfigurationMetaNames, TrainingConfigurationMetaNamesCp4d30
 from ibm_watson_machine_learning.wml_client_error import WMLClientError, ApiRequestFailure
 from ibm_watson_machine_learning.href_definitions import is_uid
+from warnings import warn
 from ibm_watson_machine_learning.wml_resource import WMLResource
 from ibm_boto3.exceptions import Boto3Error
 
@@ -199,27 +200,10 @@ class Training(WMLResource):
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_uid(training_details):
         """
-            Get training_uid from training details.
-
-            **Parameters**
-
-            .. important::
-                #. **training_details**:  Metadata of the training created\n
-                   **type**: dict\n
-
-            **Output**
-
-            .. important::
-                **returns**: Unique id of training\n
-                **return type**: str
-
-            **Example**
-
-             >>> training_details = client.training.get_details(training_uid)
-             >>> training_uid = client.training.get_uid(training_details)
-
+            This method is deprecated, please use get_id() instead."
         """
-
+        warn("This method is deprecated, please use get_id()")
+        print("This method is deprecated, please use get_id()")
         Training._validate_type(training_details, u'training_details', object, True)
         return WMLResource._get_required_element_from_dict(training_details, u'training_details', [u'metadata', u'guid'])
 
