@@ -1210,7 +1210,17 @@ def check_dependencies_versions(request_json: dict, wml_client, estimator_pkg: s
                 if package['name'] == 'autoai-libs' or package['name'] == 'numpy' \
                         or package['name'] == 'lale' or package['name'] == 'snapml':
 
-                    if package['name'] == 'snapml' and version.parse(installed_module_version) >= version.parse('1.8'):
+                    if package['name'] == 'numpy':
+                        numpy_installed_version = version.parse(installed_module_version)
+                        numpy_sw_spec_version = version.parse(package['version'])
+
+                        if numpy_installed_version.major != numpy_sw_spec_version.major:
+                            errored_packages.append(package)
+
+                        elif numpy_installed_version.minor != numpy_sw_spec_version.minor:
+                            errored_packages.append(package)
+
+                    elif package['name'] == 'snapml' and version.parse(installed_module_version) >= version.parse('1.8'):
                         package['version'] = f"<1.8.0 and >={package['version']}"
                         errored_packages.append(package)
 
@@ -1507,6 +1517,10 @@ def get_node_and_runtime_index(node_name: str, optimizer_config: dict) -> Tuple[
             node_number = i
             break
 
+        elif node_name == 'ts' and (node.get('id') == 'ts' or node.get('id') == 'autoai-ts'):
+            node_number = i
+            break
+
     for i, runtime in enumerate(optimizer_config['entity']['document']['runtimes']):
         if node_name == 'kb' and (runtime.get('id') == 'kb' or runtime.get('id') == 'automl' or
                                   runtime.get('id') == 'autoai'):
@@ -1517,6 +1531,10 @@ def get_node_and_runtime_index(node_name: str, optimizer_config: dict) -> Tuple[
             runtime_number = i
             break
 
+        elif node_name == 'ts' and runtime.get('id') == 'autoai':
+            runtime_number = i
+            break
+
     return node_number, runtime_number
 
 
@@ -1680,13 +1698,14 @@ def download_request_json(run_params: dict, model_name: str, wml_client, results
         model_output = chose_model_output(model_number)
     elif is_ts_metrics:
         model_output = 'after_final_pipelines_generation'
-    request_path = f"{schema_path.split('/data/')[0]}/assets/{run_id}_P{model_number}_{model_output}/resources/wml_model/request.json"
+
+    request_path = f"{schema_path.rsplit('/data/', 1)[0]}/assets/{run_id}_P{model_number}_{model_output}/resources/wml_model/request.json"
 
     if wml_client.ICP:
         request_str = load_file_from_file_system(wml_client=wml_client, file_path=request_path).read().decode()
         # note: only if there was 1 estimator during training
         if 'content_location' not in request_str:
-            request_path = f"{schema_path.split('/data/')[0]}/assets/{run_id}_P{model_number}_compose_model_type_output/resources/wml_model/request.json"
+            request_path = f"{schema_path.rsplit('/data/', 1)[0]}/assets/{run_id}_P{model_number}_compose_model_type_output/resources/wml_model/request.json"
             request_str = load_file_from_file_system(wml_client=wml_client, file_path=request_path).read().decode()
 
     else:
@@ -1812,13 +1831,18 @@ def validate_optimizer_enum_values(
             estimators_enum = ForecastingAlgorithms
         else:
             estimators_enum = ClassificationAlgorithms
-    for (sequence, enum_class) in (
-            ([prediction_type], PredictionType),
-            (daub_include_only_estimators, estimators_enum),
-            (include_only_estimators, estimators_enum),
-            (cognito_transform_names, Transformers),
-            ([t_shirt_size], TShirtSize),
-            (imputation_strategies, ImputationStrategy)):
+
+    sequence_enums_pairs = [
+        ([prediction_type], PredictionType),
+        (daub_include_only_estimators, estimators_enum),
+        (include_only_estimators, estimators_enum),
+        (cognito_transform_names, Transformers),
+        ([t_shirt_size], TShirtSize),
+        (imputation_strategies, ImputationStrategy)
+    ]
+    if scoring is not None:
+        sequence_enums_pairs.append(([scoring], Metrics))
+    for (sequence, enum_class) in sequence_enums_pairs:
         is_list_composed_from_enum(sequence, enum_class)
 
 
